Module account_data_api

Module account_data_api 

Enums

GetAccountDetailsError
struct for typed errors of method get_account_details
GetAccountFundingRateHistoryError
struct for typed errors of method get_account_funding_rate_history
GetAccountPreferencesError
struct for typed errors of method get_account_preferences
GetAccountTradesError
struct for typed errors of method get_account_trades
GetAccountTransactionHistoryError
struct for typed errors of method get_account_transaction_history
GetAccountValueHistoryByAccountError
struct for typed errors of method get_account_value_history_by_account
GetAccountValueHistoryError
struct for typed errors of method get_account_value_history
PatchAccountGroupIdError
struct for typed errors of method patch_account_group_id
PutAccountPreferencesError
struct for typed errors of method put_account_preferences
SponsorTxError
struct for typed errors of method sponsor_tx

Functions

get_account_details
Retrieves the user’s account details.
get_account_funding_rate_history
Retrieves the funding rate history for a specific account.
get_account_preferences
Retrieves the user’s account preferences.
get_account_trades
Retrieves the user’s trade history.
get_account_transaction_history
Retrieves the user’s transaction history (any change in balance).
get_account_value_history
Retrieves the account value history for a specific account over a given time interval.
get_account_value_history_by_account
Retrieves the account value history for 24h.
patch_account_group_id
Sets or updates the group ID for a specific account. Accounts belonging to the same group cannot trade against each other. If the groupId is not set, the account will be removed from its group. Only the first 6 characters of the groupID are guaranteed to be respected, longer group IDs may be rejected.
put_account_preferences
Update user’s account preferences. This will overwrite the preferences, so always send the full object.
sponsor_tx
Sponsors a transaction if it’s eligible for sponsorship based on allowlisted methods and kinds.