TickerResponse

Struct TickerResponse 

pub struct TickerResponse {
Show 33 fields pub symbol: String, pub last_quantity_e9: String, pub last_time_at_millis: i64, pub last_price_e9: String, pub last_funding_rate_e9: String, pub next_funding_time_at_millis: i64, pub avg_funding_rate8hr_e9: String, pub oracle_price_e9: String, pub oracle_price_direction: i64, pub mark_price_e9: String, pub mark_price_direction: i64, pub market_price_e9: String, pub market_price_direction: i32, pub best_bid_price_e9: String, pub best_bid_quantity_e9: String, pub best_ask_price_e9: String, pub best_ask_quantity_e9: String, pub open_interest_e9: String, pub high_price24hr_e9: String, pub low_price24hr_e9: String, pub volume24hr_e9: String, pub quote_volume24hr_e9: String, pub close_price24hr_e9: String, pub open_price24hr_e9: String, pub close_time24hr_at_millis: i64, pub open_time24hr_at_millis: i64, pub first_id24hr: i64, pub last_id24hr: i64, pub count24hr: String, pub price_change24hr_e9: String, pub price_change_percent24hr_e9: String, pub updated_at_millis: i64, pub estimated_funding_rate_e9: String,
}

Fields

symbol: String

Market symbol.

last_quantity_e9: String

Last trade quantity (e9 format).

last_time_at_millis: i64

Last trade time in milliseconds.

last_price_e9: String

Last trade price (e9 format).

last_funding_rate_e9: String

Funding rate value (e9 format).

next_funding_time_at_millis: i64

Time in milliseconds of next funding rate update.

avg_funding_rate8hr_e9: String

8 hr average funding rate (e9 format).

oracle_price_e9: String

Oracle price of the asset (e9 format).

oracle_price_direction: i64

Direction of oracle price computed by comparing current oracle price to last oracle price. 0 = no change, -1 = negative trend (current < last), 1 positive trend (current > last).

mark_price_e9: String

Mark price on the exchange (e9 format).

mark_price_direction: i64

Direction of mark price computed by comparing current mark price to last mark price. 0 = no change, -1 = negative trend (current < last), 1 positive trend (current > last).

market_price_e9: String

Simple average of bestBid and bestAsk. lastPrice if either is not present (e9 format).

market_price_direction: i32

Direction of market price computed by comparing current market price to last market price. 0 = no change, -1 = negative trend (current < last), 1 positive trend (current > last).

best_bid_price_e9: String

Best bid price (e9 format).

best_bid_quantity_e9: String

Best bid quantity (e9 format).

best_ask_price_e9: String

Best ask price (e9 format).

best_ask_quantity_e9: String

Best ask quantity (e9 format).

open_interest_e9: String

Open interest value (e9 format).

high_price24hr_e9: String

Highest Price in the last 24hrs (e9 format).

low_price24hr_e9: String

Lowest Price in the last 24hrs (e9 format).

volume24hr_e9: String

Total market volume in last 24hrs of asset (e9 format).

quote_volume24hr_e9: String

Total market volume in last 24hrs in USDC (e9 format).

close_price24hr_e9: String

Close price 24hrs ago (e9 format).

open_price24hr_e9: String

Open price in the last 24hrs (e9 format).

close_time24hr_at_millis: i64

24 hour close time in milliseconds.

open_time24hr_at_millis: i64

24 hour open time in milliseconds.

first_id24hr: i64

First trade id in 24hr.

last_id24hr: i64

Last trade id in 24hr.

count24hr: String

Total number of trades in 24hr.

price_change24hr_e9: String

24hr Market price change (e9 format).

price_change_percent24hr_e9: String

24hr Market price change in percentage (e9 format).

updated_at_millis: i64

Last update time in milliseconds.

estimated_funding_rate_e9: String

Live estimated funding rate based on current hour’s average market and oracle prices (e9 format).

Implementations

Source

impl TickerResponse

pub fn new( symbol: String, last_quantity_e9: String, last_time_at_millis: i64, last_price_e9: String, last_funding_rate_e9: String, next_funding_time_at_millis: i64, avg_funding_rate8hr_e9: String, oracle_price_e9: String, oracle_price_direction: i64, mark_price_e9: String, mark_price_direction: i64, market_price_e9: String, market_price_direction: i32, best_bid_price_e9: String, best_bid_quantity_e9: String, best_ask_price_e9: String, best_ask_quantity_e9: String, open_interest_e9: String, high_price24hr_e9: String, low_price24hr_e9: String, volume24hr_e9: String, quote_volume24hr_e9: String, close_price24hr_e9: String, open_price24hr_e9: String, close_time24hr_at_millis: i64, open_time24hr_at_millis: i64, first_id24hr: i64, last_id24hr: i64, count24hr: String, price_change24hr_e9: String, price_change_percent24hr_e9: String, updated_at_millis: i64, estimated_funding_rate_e9: String, ) -> TickerResponse