Enums
- GetAccount
Details Error - struct for typed errors of method
get_account_details - GetAccount
Funding Rate History Error - struct for typed errors of method
get_account_funding_rate_history - GetAccount
Preferences Error - struct for typed errors of method
get_account_preferences - GetAccount
Trades Error - struct for typed errors of method
get_account_trades - GetAccount
Transaction History Error - struct for typed errors of method
get_account_transaction_history - GetAccount
Value History ByAccount Error - struct for typed errors of method
get_account_value_history_by_account - GetAccount
Value History Error - struct for typed errors of method
get_account_value_history - Patch
Account Group IdError - struct for typed errors of method
patch_account_group_id - PutAccount
Preferences Error - struct for typed errors of method
put_account_preferences - Sponsor
TxError - struct for typed errors of method
sponsor_tx
Functions
- get_
account_ details - Retrieves the user’s account details.
- get_
account_ funding_ rate_ history - Retrieves the funding rate history for a specific account.
- get_
account_ preferences - Retrieves the user’s account preferences.
- get_
account_ trades - Retrieves the user’s trade history.
- get_
account_ transaction_ history - Retrieves the user’s transaction history (any change in balance).
- get_
account_ value_ history - Retrieves the account value history for a specific account over a given time interval.
- get_
account_ value_ history_ by_ account - Retrieves the account value history for 24h.
- patch_
account_ group_ id - Sets or updates the group ID for a specific account. Accounts belonging to the same group cannot trade against each other. If the groupId is not set, the account will be removed from its group. Only the first 6 characters of the groupID are guaranteed to be respected, longer group IDs may be rejected.
- put_
account_ preferences - Update user’s account preferences. This will overwrite the preferences, so always send the full object.
- sponsor_
tx - Sponsors a transaction if it’s eligible for sponsorship based on allowlisted methods and kinds.